# chipys-5e-tools

[![PyPI - Version](https://img.shields.io/pypi/v/chipys-5e-tools.svg)](https://pypi.org/project/chipys-5e-tools)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/chipys-5e-tools.svg)](https://pypi.org/project/chipys-5e-tools)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)
- [chipy](https://chipy.dev)

## Installation

```console
pip install chipys-5e-tools
```
v0.1.1 is now live with basic Hit-roll-vs-AC simulations 

## Sample GUI

![Main GUI Image](chipys_5e_tools/img/demo_main.png)
![Report GUI Image](chipys_5e_tools/img/demo_report.png)


## License

`chipys-5e-tools` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
